# Contribution Log

**Contributor:** Ben (me@nutchanon.org)

Start in V2, Dec 9 2025

## Test Data

Bank statement email filters:
- KBank: `from:info@kasikornbank.com subject:"e-Statement"`
- BBL: `from:no-reply@bangkokbank.com subject:"e-Statement"`
- SCB: `from:scbeasy@scb.co.th subject:"e-Statement"`

as well as PDFs for parsing.

QR code reference:
- https://developer.scb/assets/documents/documentation/qr-payment/extracting-data-from-mini-qr.pdf

sample test slips

| Date | Hours | Work |
|------|-------|------|
| 2025-12-10 | 48 | v2 - restructure, create sub-libs |
